pub struct DriverFenceAllocation<'a, T: Send + Sync + FenceContextOps> { /* private fields */ }Expand description
A pre-prepared DMA fence, carrying the user’s data and the memory it and the
fence reside in. Only useful for creating a DriverFence. Splitting
allocation and full initialization is necessary because fences cannot be
allocated dynamically in some circumstances (deadlock).
Implementations
Sourceimpl<'a, T: Send + Sync + FenceContextOps> DriverFenceAllocation<'a, T>
impl<'a, T: Send + Sync + FenceContextOps> DriverFenceAllocation<'a, T>
Sourcepub fn new_fence(self) -> DriverFence<'a, T>
pub fn new_fence(self) -> DriverFence<'a, T>
Create a new DriverFence, the signalable counterpart of a Fence.
This increments the sequence number in the associated FenceContext.