Fence

Struct Fence 

pub struct Fence { /* private fields */ }
The receiving counterpart of a DriverFence.

The Rust DMA fence implementation has a dualistic design: DriverFences are the producer-side, intended to be always owned by only one party. That party has the monopoly on signaling the fence.

A Fence is the counterpart for consumers. Thus, Fences are always refcounted and can shared with an arbitrary number of parties, including userspace. A Fence can only be used for actions such as checking the fence’s status or for registering callbacks on it.

Once the associated DriverFence signals, all FenceCallbackRegistrations registered on the Fence will be executed.

A Fence can arbitrarily outlive its DriverFence and the FenceContext. Signaling a DriverFence decouples it from its Fences.

Implementations

Source

impl Fence

pub fn is_signaled(&self) -> bool

Check whether the fence was signaled at the moment of the function call.

Note that this can return true for a Fence whose DriverFence has not yet been dropped. The reason is that the fence ops callbacks can cause the fence to get signaled by the C backend.

pub fn seqno(&self) -> u64

Get the fence’s sequence number.

pub unsafe fn from_raw<'a>(ptr: *mut dma_fence) -> &'a Self

Create a Fence from a raw C [bindings::dma_fence].

Safety

ptr must point to an initialized fence that is embedded into a Fence.