FenceCallbackRegistration

Struct FenceCallbackRegistration 

pub struct FenceCallbackRegistration<T: FenceCallback + 'static> { /* private fields */ }
A callback registration on a fence.

When this object is dropped, the callback is automatically removed if it hasn’t been called yet.

Implementations

Source

impl<T: FenceCallback + 'static> FenceCallbackRegistration<T>

pub fn project<'__pin>( self: Pin<&'__pin mut Self>, ) -> FenceCallbackRegistrationProjection<'__pin, T>

Pin-projects all fields of Self.

These fields are structurally pinned:

  • callback_foreign

These fields are not structurally pinned:

  • callback
  • fence
Source

impl<T: FenceCallback> FenceCallbackRegistration<T>

pub fn new<'a>( fence: &'a Fence, callback: T, ) -> impl PinInit<Self, CallbackError<T>> + 'a
where T: 'a,

Create a PinInit closure for registering a callback on a fence.

The actual attempt at registering the callback will take place once you call an allocator’s pin_init() function.

On success the callback is pinned in place and will fire when the fence signals. On AlreadySignaled the callback is returned to the caller so that owned resources can be reclaimed.

pub fn fence(&self) -> &Fence

Returns a reference to the fence this callback is registered on.