FenceContext

Struct FenceContext 

pub struct FenceContext<T: FenceContextOps + Send + Sync> { /* private fields */ }
A dma-fence context. A fence context takes care of associating related fences with each other, providing each with raising sequence numbers and a common identifier.

Implementations

Source

impl<T: FenceContextOps + Send + Sync> FenceContext<T>

pub fn project<'__pin>( self: Pin<&'__pin mut Self>, ) -> FenceContextProjection<'__pin, T>

Pin-projects all fields of Self.

These fields are structurally pinned:

  • data

These fields are not structurally pinned:

  • nr
  • seqno
  • driver_name
  • timeline_name
  • nr_of_unsignaled_fences
Source

impl<'a, T: Send + Sync + FenceContextOps> FenceContext<T>

pub fn new<E>( initial_seqno: u64, driver_name: &CStr, timeline_name: &CStr, data: impl PinInit<T, E>, ) -> impl PinInit<Self, Error>
where Error: From<E>,

Create a new FenceContext.

pub fn new_fence_allocation( &self, data: T::FenceDataType, ) -> Result<DriverFenceAllocation<'_, T>>

Allocate the memory for a DriverFence and already store data inside.

This is needed because many times, creation of a DriverFence must not fail, and allocating might deadlock in some situations.

The data you pass here must not perform any operations that are illegal in atomic context in its Drop implementation.