pub struct FenceCallbackRegistration<T: FenceCallback + 'static> { /* private fields */ }Expand description
A callback registration on a fence.
When this object is dropped, the callback is automatically removed if it hasn’t been called yet.
Implementations
Sourceimpl<T: FenceCallback + 'static> FenceCallbackRegistration<T>
impl<T: FenceCallback + 'static> FenceCallbackRegistration<T>
Sourceimpl<T: FenceCallback> FenceCallbackRegistration<T>
impl<T: FenceCallback> FenceCallbackRegistration<T>
Sourcepub fn new<'a>(
fence: &'a Fence,
callback: T,
) -> impl PinInit<Self, CallbackError<T>> + 'awhere
T: 'a,
pub fn new<'a>(
fence: &'a Fence,
callback: T,
) -> impl PinInit<Self, CallbackError<T>> + 'awhere
T: 'a,
Create a PinInit closure for registering a callback on a fence.
The actual attempt at registering the callback will take place once you
call an allocator’s pin_init() function.
On success the callback is pinned in place and will fire when the fence
signals. On AlreadySignaled the callback is returned to the caller so
that owned resources can be reclaimed.