pub struct FenceContext<T: FenceContextOps + Send + Sync> { /* private fields */ }Expand description
A dma-fence context. A fence context takes care of associating related fences with each other, providing each with raising sequence numbers and a common identifier.
Implementations
Sourceimpl<T: FenceContextOps + Send + Sync> FenceContext<T>
impl<T: FenceContextOps + Send + Sync> FenceContext<T>
Sourceimpl<'a, T: Send + Sync + FenceContextOps> FenceContext<T>
impl<'a, T: Send + Sync + FenceContextOps> FenceContext<T>
Sourcepub fn new<E>(
initial_seqno: u64,
driver_name: &CStr,
timeline_name: &CStr,
data: impl PinInit<T, E>,
) -> impl PinInit<Self, Error>
pub fn new<E>( initial_seqno: u64, driver_name: &CStr, timeline_name: &CStr, data: impl PinInit<T, E>, ) -> impl PinInit<Self, Error>
Create a new FenceContext.
Sourcepub fn new_fence_allocation(
&self,
data: T::FenceDataType,
) -> Result<DriverFenceAllocation<'_, T>>
pub fn new_fence_allocation( &self, data: T::FenceDataType, ) -> Result<DriverFenceAllocation<'_, T>>
Allocate the memory for a DriverFence and already store data inside.
This is needed because many times, creation of a DriverFence must not
fail, and allocating might deadlock in some situations.
The data you pass here must not perform any operations that are illegal
in atomic context in its Drop implementation.